@@ -1,4 +1,5 @@
 // the libaries of using
+use dirs;
 use rand_core;
 use smol;
 use sosistab;
@@ -14,7 +15,7 @@ use x25519_dalek::{PublicKey, StaticSecret};
 
 use smol::prelude::*;
 
-const VERSION: &str = "1.0.2";
+const VERSION: &str = "1.0.3";
 
 async fn genkey() -> StaticSecret {
     let mut key: [u8; 32] = [0u8; 32];
@@ -25,12 +26,12 @@ async fn genkey() -> StaticSecret {
 }
 
 async fn takekey() -> StaticSecret {
-    let me: String = env::current_exe()
+    let home: String = dirs::home_dir()
         .unwrap()
         .into_os_string()
         .into_string()
         .unwrap();
-    let keyfile: String = me + ".sosistun-private-key";
+    let keyfile: String = home + "/sosistun-private-key";
 
     let key: StaticSecret = match std::fs::read(&keyfile) {
         Ok(v) => {
